# Discover.tcl    Copyright 2000   Mark Black
#
# This function is responsible for determining if an 
# operationg system supports a given monitoring function
# It cycles throught all the *.mon files, extracting
# the procedure names.  Those procedures starting with
# a "_" will be ignored.  It then tries to run them 
# with the "discover" argument.  The results are stored
# in the $MATHOME/etc/tcl.mon file
#

proc version { args } {
    puts 1
}


proc Discover { args } {
    if { $args == "discover" } {
	return
    }
    array set f2p {}

    # Scan all the *.mon files for proc's
    set ftyps "lib/*.mon"
    puts -nonewline "Scanning"
    foreach file [eval glob $ftyps] {
	puts -nonewline "."
	catch "open $file r" retval
	if { [string range $retval 0 3 ] == "file" } {
	    # Search for procedures
	    while { [ eof $retval ] != 1 } {
		gets $retval fout
		if { [string range $fout 0 5 ] == "proc _" } {
		    continue
		}
		if { [string range $fout 0 4 ] == "proc " } {
		    set i [string wordend $fout 5 ]
		    set procname [string range $fout 5 $i ]
		    puts -nonewline "+"
		    set d [lindex [array get f2p $file ] 1 ]
		    append d $procname
		    set t $file
		    lappend t $d
		    array set f2p $t
		} 
	    }
	    close $retval
	} else {
	    # Can't read it
	}
    }
    puts ""

    # Open Output file
    set file "etc/tcl.mon"
    catch "open $file w" oFile
    if { [string range $oFile 0 3 ] != "file" } {
	puts "ERROR:  Cannot open etc/tcl.mon"
	return
    }
    puts $oFile "# Warning this file is generated automatically."
    puts $oFile "# DO NOT EDIT."
    #puts $oFile "array set tclmon2t \{100 \{ 0 b disk.gif 0a null \"Drives\" \}\}"
    #puts $oFile "array set tclmon2t \{110 \{ 0 b mem.gif 0b null \"Memory\" \}\}"
    #puts $oFile "array set tclmon2t \{120 \{ 0 b cpu.gif 0c null \"CPU\" \}\}"
    #puts $oFile "array set tclmon2t \{130 \{ 0 b moneth.gif 0d null \"Network\" \}\}"
    #puts $oFile "array set tclmon2t \{140 \{ 0 b users.gif 0e null \"Users\" \}\}"
    #puts $oFile "array set tclmon2t \{150 \{ 0 b export.gif 0f null \"NFS\" \}\}"


    # Now source the scanned files and invoke the procedures 
    # with the "discover" argument
    set srch [array startsearch f2p ]
    while { [array anymore f2p $srch ] != 0 } {
	set monFileName [ array nextelement f2p $srch ]
	set monProcedures [lindex [array get f2p $monFileName ] 1 ]
	set sourceretval ""
	puts "Processing $monFileName"
	catch "source $monFileName" sourceretval
	if { $sourceretval != "" } {
	    puts "Warning: $sourceretval"
	    continue
	}
	foreach procedure $monProcedures {
	    set d [$procedure discover ]
	    # Validate the data
	    if { [string range $d 0 4 ] != "array" } {
		if { $d != "" } {
		    puts "Invalid data, ignoring:  $d"
		}
		continue
	    }
	    puts $oFile "$d"
	}
    }
    array donesearch f2p $srch


    # Locate all of the *.scp files, and run the Discover routine
    # in each of them
    set matdjobs {}
    set d ""
    set ftyps "lib/*.scp"
    puts -nonewline "Scanning Historic Log Gathers\n"
    foreach processfile [eval glob $ftyps] {
	puts -nonewline "Processing $processfile\n"
	catch "source $processfile" sourceretval
	if { $sourceretval != "" } {
	    puts "Warning: $sourceretval"
	    catch "namespace delete Report"
	    continue
	}
	set k [catch "namespace import -force Report::Discover" ]
	if { $k != 0 } {
	    continue
	}
	set d [Report::Discover ]
	
	# Validate the data
	foreach line [split $d "\n" ] {
	    if { [string range $line 0 4 ] != "array" } {
		if { [string range $line 0 4 ] == "MATD:" } {
		    lappend matdjobs [string trimleft [string range $line 5 end ] ]
		} else {
		    if { $line == "" } {
			continue
		    }
		    puts "Invalid data, ignoring:  $line"
		}
		continue
	    }
	    puts $oFile "$line"
	}
	catch "namespace delete Report"
    }
    close $oFile

    # Open Output file
    set file "etc/matd.conf"
    catch "open $file w" oFile
    if { [string range $oFile 0 3 ] != "file" } {
	puts "ERROR:  Cannot open etc/matd.conf"
	return
    }
    puts $oFile "# Warning this file is generated automatically."
    puts $oFile "# DO NOT EDIT."
    puts $oFile "# This file was generated by MAT.  Edit with care!#"
    puts $oFile "#"
    puts $oFile "# The line format is follows:"
    puts $oFile "#   interval  jobid  minutes  type#  timeout(sec)  UID  OnError  Logfilename  retention {Job specific data}"
    puts $oFile "#   timed  jobid  min,s  hour,s  weekday,s  monthday,s  month,s  type#  timeout(sec)  UID  OnError  Logfilename  retention {Job specific data}"
    puts $oFile "#   version data   {NOTE: This is not a user definable parameter}"
    puts $oFile "# The following illustrates the form of the {Job specific data}"
    puts $oFile "#      Monitoring Jobs:    WarnFilename  Warn_Thres  Gflags  Monitor_What  {Optional Data}"
    puts $oFile "#      User Script Jobs:   ScriptFile"
    puts $oFile "#      Cleanup Job:        Log_file_to_Clean  Lines_to_Retain"
    puts $oFile "#      Replication Jobs:   ServerHost  ServerDir  ClientDir  Create_As  File_Umask  Dir_Umask"
    puts $oFile "#      Backup Jobs:        ServerHost  ListFile  ErrorScript  VolumeSet"
    puts $oFile "#      Time Sync Job:      ServerHost    (Not yet implimented)"
    puts $oFile "# Comment lines start with a '#'"
    puts $oFile "version 1 0 0 0 0 0 0 0 0"
    puts $oFile "timed 60000 55 1 * * * 8 60 0 0 var/matdlogcleaner 240"

    foreach line $matdjobs {
	puts $oFile $line
	puts "Adding MATd Task: $line"
    }

    close $oFile
}






