# outgen.tcl  Copyright 2000 Mark Black
#
# This file contains the functions for generating the 
# output formatting code based on the *.jds file.
# The command will be run as a Tcl mon command


# genHist - Generate the TCL console code to format the 
#           output.  This function must generate the code
#           based on the contents of the job description file
#           and the contents on the matd.conf
#           From the matd.conf it will gather:
#               - The name of the script file.
#               - The name of the log file.
#               - The instance data
#           From the *.jds file it will gather:
#               - The data display information
#           USE:   genHist  {Job Number}
proc genHist { args } {

    # fp - the file name prefix.  Set to "../" so it can be run from cmd
    set fp "../"

    # Read through the matd.conf for the requested job
    set logfile ""
    set jdsfile ""
    set errlvl ""
    set wrnlvl ""
    set insargs ""
    append file "etc/matd.conf"
    catch "open $file r" retval
    if { [string range $retval 0 3 ] != "file" } {
	puts "ERROR:  failed to open:  \$MATHOME/etc/matd.conf"
	return
    }
    # Search for the job
    while { [ eof $retval ] != 1 } {
	gets $retval fout
	if { [lindex [split $fout ] 1 ] != "$args" } {
	    continue
	}
	# Got the line
	set offset 7
	if { [lindex [split $fout ] 0 ] == "timed" } {
	    set offset 11
	}
	set logfile [lindex [split $fout ] $offset ]
	set jdsfile [lindex [split $fout ] [expr {$offset + 2}] ]
	set errlvl [lindex [split $fout ] [expr {$offset + 3}] ]
	set wrnlvl [lindex [split $fout ] [expr {$offset + 4}] ]
	set instanceData [lrange [split $fout ] [expr {$offset + 5}] end ]
    }
    close $retval

    if { $logfile == "" } {
	puts "ERROR:  Invalid id"
	return
    }
    if { [file exists "$logfile" ] != 1 } {
	# Error file not found
	puts "ERROR:  Log file does not exist yet: $logfile"
	return
    }
    append f1 "lib/$jdsfile.jds"
    if { [file exists "$f1" ] != 1 } {
	# Error file not found
	puts "ERROR:  Can't find Job Description file:  lib/$jdsfile.jds  pwd=[pwd]"
	return
    }
    source "$f1"

    #set Description "Test Script"
    #set ScriptName "bob"
    #set IconName "disk.gif"
    #set otype 2
    #set gtype bb2f
    #set minY "0"
    #set maxY "100"
    #set graphYlabel "Units"
    #set graphTitle "Graph Title"
    #set usd0 1
    #set usd0Desc "Disk Use"
    #set usd1 1
    #set usd1Desc "Disk Free"
    #set usd2 0
    #set usd2Desc ""
    #set usd3 0
    #set usd3Desc ""
    #set usd4 0
    #set usd4Desc ""
    #set usd5 0
    #set usd5Desc ""
    #set usd6 0

    switch -- $otype {
	0 {
	    # Text type
	    puts "MText::init"
	    regsub -all -- "instanceData" $Description "$instanceData" iDescription
	    puts "MText::title $iDescription"
	    catch "open $logfile r" retval
	    if { [string range $retval 0 3 ] != "file" } {
		puts "ERROR:  failed to open log file:  $logfile"
		return
	    }
	    while { [ eof $retval ] != 1 } {
		gets $retval fout
		puts "MText::display $fout"
	    }
	    close $retval
	}
	1 {
	    # Boolean Type
	    
	}
	2 {
	    # Numeric output. 
	    # The p2time, and p2val arrays will have to be constructed
	    # p2time is:   index { month:day:hour:minute }
	    # Data arrays MUST be set first
	    puts "global p2time p2val"
	    puts "catch { unset p2time }"
	    puts "catch { unset p2val }"
	    catch "open $logfile r" retval
	    if { [string range $retval 0 3 ] != "file" } {
		puts "ERROR:  failed to open log file:  $logfile"
		return
	    }
	    set cnt 0
	    while { [ eof $retval ] != 1 } {
		gets $retval fout
		set t [split $fout {:} ]
		if { [llength $t ] < 5 } {
		    continue
		}
		set time "[lindex $t 0]:[lindex $t 1]:[lindex $t 2]:[lindex $t 3]"
		puts "array set p2time \{$cnt $time \}"
		set darray [lrange $t 4 end ]
		set dout [list ]
		if { $usd0 == 1 } {
		    lappend dout [lindex $darray 0 ]
		}
		if { $usd1 == 1 } {
		    lappend dout [lindex $darray 1 ]
		}
		if { $usd2 == 1 } {
		    lappend dout [lindex $darray 2 ]
		}
		if { $usd3 == 1 } {
		    lappend dout [lindex $darray 3 ]
		}
		if { $usd4 == 1 } {
		    lappend dout [lindex $darray 4 ]
		}
		if { $usd5 == 1 } {
		    lappend dout [lindex $darray 5 ]
		}
		if { $usd6 == 1 } {
		    lappend dout [lindex $darray 6 ]
		}
		if { $usd7 == 1 } {
		    lappend dout [lindex $darray 7 ]
		}
		puts "array set p2val \{$cnt \{$dout\} \}"
		incr cnt 1
	    }
	    close $retval

	    puts "MGraph::create .w small"
	    regsub -all -- "instanceData" $graphTitle "$instanceData" igraphTitle
	    puts "MGraph::title .w $igraphTitle"
	    puts "MGraph::xaxis .w Time"
	    puts "MGraph::yaxis .w $graphYlabel"
	    set display ""
	    if { $usd0 == 1 } {
		append display "0"
		puts "MGraph::ledgend .w -add 0 -text \"$usd0Desc\""
	    }
	    if { $usd1 == 1 } {
		append display "1"
		puts "MGraph::ledgend .w -add 1 -text \"$usd1Desc\""
	    }
	    if { $usd2 == 1 } {
		append display "2"
		puts "MGraph::ledgend .w -add 2 -text \"$usd2Desc\""
	    }
	    if { $usd3 == 1 } {
		append display "3"
		puts "MGraph::ledgend .w -add 3 -text \"$usd3Desc\""
	    }
	    if { $usd4 == 1 } {
		append display "4"
		puts "MGraph::ledgend .w -add 4 -text \"$usd4Desc\""
	    }
	    if { $usd5 == 1 } {
		append display "5"
		puts "MGraph::ledgend .w -add 5 -text \"$usd5Desc\""
	    }
	    if { $usd6 == 1 } {
		append display "6"
		puts "MGraph::ledgend .w -add 6 -text \"$usd6Desc\""
	    }
	    if { $usd7 == 1 } {
		append display "7"
		puts "MGraph::ledgend .w -add 7 -text \"$usd7Desc\""
	    }
	    puts "MGraph::draw .w -type $gtype -grid 1 -max $maxY -min $minY -width 4 -date 1 -data $display "
	}
	3 { 
	    # Pie Chart
	    puts "MPie::init"
	    puts "MPie::create .m1 small"
	    regsub -all -- "instanceData" $Description "$instanceData" iDescription
	    puts "MPie::title .m1 $iDescription"
	}
    }	    
}
