#!/bin/sh

#  This is to be run from $MATHOME/tmp.  The upgrade files should be in 
#  the same location.

# NOTE:  Do NOT modify this script it will be overwritten when the
#        next upgrade is applied

NEW=1
export NEW

PATH=/bin:/usr/bin:/usr/etc:/usr/ucb:/usr/sbin
export PATH

# If we have input args look for -v
case "$1" in
'-v')
    echo $NEW
    exit 0
    ;;

'-1')
    echo "1"
    exit 0
    ;;
esac

MATHOME="$PWD"
if [ -z "$MATHOME" ]; then
	MATHOME="/var/mat"
fi
MATBIN="$MATHOME/bin"
MATTMP="$MATHOME/tmp"
MATSRC="$MATHOME/scripts"
MATLIB="$MATHOME/lib"

# Get the version of the MATd
MVER=`$MATBIN/matd -v |awk -F' ' '{ print $1 }'`

echo "MAT version $MVER found"

if [ `expr $MVER = 0.24 \| $MVER = 0.20 \| $MVER = 0.21 \| $MVER = 0.22 \| $MVER = 0.23` ]; then
    # As of 0.19 all scripts provide version numbers.  Only the lower
    # version scripts will be replaced.
    for i in `cat $MATTMP/catalog` ;
    do
	# Check versions
	CVER=`$MATTMP/$i -v`
        if [ -f $MATSRC/$i ]; then
	    VER=`$MATSRC/$i -v |awk -F' ' '{ print $1 }'`
	    if [ $CVER -gt $VER ]; then
		echo "Upgrading MAT script $i.  Old version $VER.  New version $CVER"
		mv $MATTMP/$i $MATSRC/$i
		chmod 755 $MATSRC/$i
	    else
		echo "No upgrade of $i.  Old version $VER.  New version $CVER"
		rm $MATTMP/$i
	    fi
	else
	    echo "MAT script $i not found.  Adding."
	    mv $MATTMP/$i $MATSRC/$i
	    chmod 755 $MATSRC/$i
	fi
    done
else
    echo "Pre 0.19 MAT install.  Replacing all scripts"
    for i in `cat $MATTMP/catalog` ;
    do
	# The older versions of the scripts did not support "-v", so
	# we have to replace them blindly
	echo "Upgrading MAT script $i"
	mv $MATTMP/$i $MATSRC/$i
        chmod 755 $MATSRC/$i
   done

fi

rm $MATTMP/catalog

# Upgrade tape Library
mv $MATTMP/libtape.s* $MATBIN/
chmod 755 $MATBIN/libtape.s*

mv $MATTMP/libmattcl.s* $MATBIN/
chmod 755 $MATBIN/libmattcl.s*

if [ -f $MATTMP/libscram.so ]; then
    echo "Upgrading Encryption Lib"
    mv $MATTMP/libscram.so $MATBIN/libscram.so
    chmod 755 $MATBIN/libscram.so
    if [ -f $MATHOME/etc/MATkey ]; then
	echo "Found Encryption Key"
    else
	echo "Encryption Key NOT found!  Setting to: 12345678"
	echo "Edit:  $MATHOME/etc/MATkey  to change"
	echo "12345678" > $MATHOME/etc/MATkey
    fi
fi
if [ -f $MATTMP/libscram.sl ]; then
    echo "Upgrading Encryption Lib"
    mv $MATTMP/libscram.sl $MATBIN/libscram.sl
    chmod 755 $MATBIN/libscram.sl
    if [ -f $MATHOME/etc/MATkey ]; then
	echo "Found Encryption Key"
    else
	echo "Encryption Key NOT found!  Setting to: 12345678"
	echo "Edit:  $MATHOME/etc/MATkey  to change"
	echo "12345678" > $MATHOME/etc/MATkey
    fi
fi

# Upgrade the MATd binary
if [ -f $MATBIN/matd ]; then
    echo "Upgrading MATd"
    mv $MATTMP/matd $MATBIN/matd
else
    echo "MATd not found.  Adding."
    mv $MATTMP/matd $MATBIN/matd
fi
chmod 755 $MATBIN/matd

echo "The matd needs to be restarted."
echo "Different Linux ps's make this difficult to script."

# Add the directories and files necessary for the tape code
if [ -d $MATHOME/var/tape/jobids ]; then
    echo "Already configured for tapes"
else
    echo "Making backup job request directory"
    mkdir -p $MATHOME/var/tape/jobids
    touch $MATHOME/var/tape/jobids/index
    touch $MATHOME/var/tape/jobids/group
fi
touch $MATHOME/var/tape/bhistory

# Upgrade the MAT cmd binary
if [ -f $MATBIN/cmd ]; then
    echo "Upgrading MAT cmd"
    mv $MATTMP/cmd $MATBIN/cmd
else
    echo "MAT cmd not found.  Adding."
    mv $MATTMP/cmd $MATBIN/cmd
fi
chmod 755 $MATBIN/cmd

# Add the password entry if needed
if [ -f $MATHOME/etc/MATpass ]; then
	HAV=`grep root:MB $MATHOME/etc/MATpass`
	if [ -n "$HAV" ]; then
		echo "*** WARNING ***  The root password is in the old format"
		echo "Updating, and resetting back to default ie:  bye"
		sed s/root:MB.*// < $MATHOME/etc/MATpass > $MATHOME/etc/MATpass.new
		mv $MATHOME/etc/MATpass.new $MATHOME/etc/MATpass 
    		echo "root:MCGbE|h0_b6Bu1qAjgZFlOZF8M:0" >> $MATHOME/etc/MATpass
	fi
	HAV=`grep archive_user:MB $MATHOME/etc/MATpass`
	if [ -n "$HAV" ]; then
		sed s/archive_user:MB.*// < $MATHOME/etc/MATpass > $MATHOME/etc/MATpass.new
		mv $MATHOME/etc/MATpass.new $MATHOME/etc/MATpass 
    		echo "archive_user:MCM5uW|sTxxA_1qAZlithP90xd:c" >> $MATHOME/etc/MATpass
	fi
    HAV=`grep archive_user $MATHOME/etc/MATpass`
    if [ -z "$HAV" ]; then
	echo "archive_user:MCM5uW|sTxxA_1qAZlithP90xd:c" >> $MATHOME/etc/MATpass
    fi
else
    echo "** WARNING **  MATpass not found.  Creating!"
    echo "root:MCGbE|h0_b6Bu1qAjgZFlOZF8M:0" > $MATHOME/etc/MATpass
    echo "archive_user:MCM5uW|sTxxA_1qAZlithP90xd:c" >> $MATHOME/etc/MATpass
fi
chmod 600 $MATHOME/etc/MATpass

# Clean up
if [ -f $MATTMP/mat.tar ]; then
    rm $MATTMP/mat.tar
fi
if [ -f $MATTMP/Umat.000 ]; then
    rm $MATTMP/Umat.000
fi

# Add Licenses
echo "dns:*:0:11504:o62E8Za|LUdPe:" > $MATHOME/etc/MATlic.dat
echo "nfs:*:0:11504:mHyM|RctN5fXg:" >> $MATHOME/etc/MATlic.dat
echo "nis:*:0:11504:bGvBs5l2ARiWh:" >> $MATHOME/etc/MATlic.dat
echo "rep:*:0:11504:rHeM1R0tR5zX2:" >> $MATHOME/etc/MATlic.dat
echo "mon:*:0:11504:g7nYkFt1YIqLp:" >> $MATHOME/etc/MATlic.dat
echo "tps:*:0:11504:a9u4pDobBKjNk:" >> $MATHOME/etc/MATlic.dat
echo "gen:*:0:11504:gVnSkLtjYCqFp:" >> $MATHOME/etc/MATlic.dat
echo "mky:*:0:11504:cO3JxUgsJZb_c:" >> $MATHOME/etc/MATlic.dat
chmod 644 $MATHOME/etc/MATlic.dat

# Add the files for user supplied monitoring
if [ -d $MATLIB ]; then
    echo "MATLIB found"
else
    mkdir $MATLIB
fi
touch $MATLIB/linux.scp
touch $MATLIB/solaris.scp
touch $MATLIB/sunos.scp
touch $MATLIB/irix.scp
touch $MATLIB/hpux.scp
mv $MATTMP/Discover.tcl $MATLIB/
mv $MATTMP/outgen.tcl $MATLIB/
mv $MATTMP/*.mon $MATLIB/
mv $MATTMP/*.scp $MATLIB/
mv $MATTMP/*.jds $MATLIB/
mv $MATTMP/*.err $MATLIB/
mv $MATTMP/*.wrn $MATLIB/

# Run the Discovery to build the OS specific monitoring values
( cd $MATBIN ;./cmd MATTCL mon Discover.tcl Discover ) 

# Terminate communications with the MAT console, before 
# trying to replace the matagent binary
echo "TRANSFER OK"

# Upgrade the MAT agent binary
if [ -f $MATBIN/matagent ]; then
    echo "Upgrading MAT agent"
    mv $MATTMP/matagent $MATBIN/matagent
else
    echo "MAT agent not found.  Adding."
    mv $MATTMP/matagent $MATBIN/matagent
fi
chmod 755 $MATBIN/matagent




